% % % 2 DYNAMICS
%type_shock           = 0; % 0 inflation 1 sudden stop 2 transition dynamics 3 initial zero inflation
%timeless             = 0; % If zero, zero-optimal policies, if 1 timeless optimal
parameters.timeless  = timeless;
initial_dist         = 0; %0 uniform, 1 delta,

%path for pi / r_bar
%T      = 200;            % Number of years of the transition
dt     = 1/12;            % Time interval
rho_pi = (0.0001)^dt;     % persistence of inflation (expressed in annual terms)
rho_r_bar = (1-0.5*dt);    % persistence of interest rate shocks (expressed in annual terms)
rho_Y     =  (1-0.5*dt);     % persistence of TFP(expressed in annual terms)
N      = T/dt;            % number of time intervals
%r_init = 0.01;            % initial r in asudden stop

% Initial distribution
f0   = distribution; % Initial = SS distribution

%Case 1: Monetary policy shock
pi_n     = zeros(1,N);
r_bar_n  = r_bar * ones(1,N);
Y_n      = ones(1,N);
if type_shock == 0 %inflation shock
    pi_n(1)  = 0.05;
    for n=2:N
        pi_n(n) = pi_n(n-1) *rho_pi;
    end
else
    
    if type_shock == 1 %interest rate shock
        r_bar_n(1)  = r_init;
        for n=2:N
            r_bar_n(n) = (1-rho_r_bar)*r_bar + r_bar_n(n-1) *rho_r_bar;
        end
    else               
        if type_shock == 4 %TFP shock
            Y_n(1)  = Y_init;
            for n=2:N
                Y_n(n) = (1-rho_Y)*1 + Y_n(n-1) *rho_Y;
            end
        else   % transistional dynamics
            
            if initial_dist         == 0
                f0        = zeros(I,2);
                range = find(results.a<2,1,'last');
                f0(1:range,:)= 1;
            else
                f0        = zeros(I,2);
                range = find(results.a<0,1,'last');
                f0(range,:) = 1;
            end
            
            f0(:,1)  =  f0(:,1) * la2 /(la2+la1);
            f0(:,2)  =  f0(:,2) * la1 /(la2+la1);
            
            f0_sum    = sum(sum(f0*results.da));
            f0        = f0/f0_sum;
        end    

    end
end

if type_shock == 3   
    results_0      = HJB_stationary(parameters,0);
    f0             = KFE_stationary(parameters,results_0);
end
 

%%
% Step 0. Steady_state distribution
results_ss        = results;
parameters.dt     = dt;
parameters.N      = N;

if mode == 1 % Exogenos temporary inflation/ROW interest rate  shock
    % Steps 1&2. Bond pricing and HJB
    results           = HJB_dynamics(parameters,results, pi_n,r_bar_n,Y_n);
    
    % Step 3. KF
    f = KFE_dynamics(parameters,results,f0);
else         % optimal monetary policy
    results.f0            = f0;
    parameters.xi         = 0.05;         % adjustment parameter
    parameters.crit_pi    = 2*10^(-4);    % convergence ctrit algorithm   
    parameters.maxit_pi   = 100;          % convergence ctrit algorithm  
    %Step 4
    if mode ==0 
        pi_n = optimal_dynamics(parameters,r_bar_n,results,pi,Y_n);
    else
        pi_n = ramsey_dynamics(parameters,r_bar_n,results,pi,Y_n);
    end
    % Steps 1&2. Bond pricing and HJB
    results           = HJB_dynamics(parameters,results, pi_n,r_bar_n,Y_n);
    % Step 3. KF
    f = KFE_dynamics(parameters,results,f0);
end

if type_shock     == 0
    plotting_inflation
else
    plotting_IRFS
end




