% % %---------------------------------
% % % 2 DYNAMICS - ONLY IN CASE OF SUDDEN STOP, modes 1 or 2
permanent  = 0; % Depending on the value it is transitory (0) or permanent (1) or transitory with reset (2)
timeless   = 0; % If zero, zero-optimal policies, if 1 timeless optimal
parameters.timeless  = timeless;

%path for pi / r_bar
T       = 200;             % Number of years of the transition
dt      = 1/12;           % Time interval
rho_r_bar = (0.5)^dt;     % persistence of sudden stop (expressed in annual terms)
N         = T/dt;         % number of time intervals

% Initial distribution
f0(:,1)        = construct_initial_dist(amin,amax,I);
f0(:,2)        = f0(:,1) ;
f0(:,1)  =  f0(:,1) * la2 /(la2+la1);
f0(:,2)  =  f0(:,2) * la1 /(la2+la1);

f0_sum    = sum(sum(f0*results.da));
f0        = f0/f0_sum;

r_bar_n  = r_bar * ones(1,N);

%Construction of the interest rates path
if permanent == 0 %transitory
        r_bar_n(1)= r_bar + 0.02;
    for n=2:N
        r_bar_n(n) = (1-rho_r_bar)*r_bar + r_bar_n(n-1) *rho_r_bar;
    end
else
    if  permanent == 1           % permanent
        r_bar_0           = r_bar; %initial r_bar
        r_bar             = 0.025; %final r_bar
        parameters.r_bar  = r_bar;
        if mode ==0       % optimal under discretion
            pi           = fzero(@(pi) optimal_stationary(parameters,pi), pi_guess);
        else
            flag_mu      = 0;
            pi           = fzero(@(pi) ramsey(parameters,pi,flag_mu), pi_guess);
        end
        results      = HJB_stationary(parameters,pi);
        distribution = KFE_stationary(parameters,results); %Final distribution
        
        r_bar_n(1)  = r_bar_0;
        for n=2:N
            r_bar_n(n) = (1-rho_r_bar)*r_bar + r_bar_n(n-1) *rho_r_bar;
        end
    else % transitory with reset
        % in this case there is nothing to do, the initial and final distributions coincide and r_bar is constant    
    end    
end
%%

% Step 0. Steady_state distribution
results_ss        = results;
parameters.dt     = dt;
parameters.N      = N;
results.f0            = f0;
parameters.xi         = 0.05;         % adjustment parameter
parameters.crit_pi    = 5*10^(-5); % convergence ctrit algorithm
parameters.maxit_pi   = 100;     % convergence ctrit algorithm
%Step 4
if mode ==0
    pi_n = optimal_dynamics(parameters,r_bar_n,results,pi);
else
    pi_n = ramsey_dynamics(parameters,r_bar_n,results,pi);
end
% Steps 1&2. Bond pricing and HJB
results           = HJB_dynamics(parameters,results, pi_n,r_bar_n);
% Step 3. KF
f = KFE_dynamics(parameters,results,f0);

plotting_inflation
