function pi_n = ramsey_dynamics(parameters,r_bar_n,results,pi,Y_n)
%This code computes the optimal inflation rate under discretion with
%dynamics
% Developped by Nuo and Thomas (2015)
xi            = parameters.xi;
gamma         = parameters.gamma;
maxit         = parameters.maxit_pi;         % max number of iterations
delta         = parameters.delta;            % debt duration 1/lambda
rho           = parameters.rho;              % discount rate
dt            = parameters.dt;               % dt in HJB
N             = parameters.N;                % Time period in dt
psi           = parameters.psi;              % inflation costs
f0            = results.f0;
pi_n          = zeros(1,N);                  % Initial guess
output        = zeros(1,N);
mu_n          = zeros(1,N);                  % Lagrange multiplier

pi_n(:)       = pi; % we assign the steady state value to all elements

%mu_n(N)       = ramsey(parameters,pi,1);  %This is used in the case backward - looking
if parameters.timeless ==0
    mu_n(1) = 0;                              % zero optimal
else
    mu_n(1)       = ramsey(parameters,pi,1);  % timeless
end

for l=1:maxit
    results           = HJB_dynamics(parameters,results, pi_n,r_bar_n,Y_n);
    f = KFE_dynamics(parameters,results,f0);
    
    output(1)            = sum(sum(f{1}(:,:).*results.aa(:,:).*results.c_n(:,:,1).^(-gamma)*results.Q_n(1) *results.da  )) + psi*pi_n(1) -results.Q_n(1) * mu_n(1);
    for n=2:1:N
        num              = sum(sum(f{n}(:,:).*(results.aa(:,:)*delta + Y_n(n)*results.zz(:,:)-results.c_n(:,:,n)).*results.c_n(:,:,n).^(-gamma) *results.da));
        mu_n(n)          = mu_n(n-1) + dt * mu_n(n-1) * (rho - r_bar_n(n) -pi_n(n) -delta) + dt /(results.Q_n(n)) *  num;
        output(n)        = sum(sum(f{n}(:,:).*results.aa(:,:).*results.c_n(:,:,n).^(-gamma) *results.Q_n(n) *results.da)) + psi*pi_n(n) -results.Q_n(n) * mu_n(n);
    end
    
    pi_n = pi_n - xi *output;
    dist = max(abs(output));
    disp('distance to convergence')
    disp(dist)
    disp('iteration')
    disp(l)
    if dist<parameters.crit_pi
        disp('Optimal monetary converged, Iteration = ')
        disp(l)
        break
    end
end

if l == maxit
    disp('maximum number of iterations  optimal inflation')
end
